@@ -133,6 +133,9 @@ olink_ttest <- function(df, variable, pair_id, ...){
   #Check data format
   npxCheck <- npxCheck(df)
 
+  # Rename duplicate UniProts
+  df <- uniprot_replace(df, npxCheck)
+
   nas_in_level <- df  %>%
     dplyr::filter(!(OlinkID %in% npxCheck$all_nas)) %>%
     dplyr::group_by(OlinkID, !!rlang::ensym(variable)) %>%
