@@ -15,20 +15,24 @@ test_that("olink_bridgeselector works", {
   expect_warning(olink_bridgeselector(npx_data_format221010, sampleMissingFreq = 0.1, n = 2))
   ref_data <- npx_data1 |> olink_bridgeselector(sampleMissingFreq = 0.1, n = 8)
   ml_data <- npx_data1 |>
-    dplyr::mutate(`Max LOD` = LOD) |> 
-    dplyr::select(-LOD) |> 
+    dplyr::mutate(`Max LOD` = LOD) |>
+    dplyr::select(-LOD) |>
     olink_bridgeselector(sampleMissingFreq = 0.1, n = 8)
   pl_data <- npx_data1 |>
-    dplyr::mutate(`Plate LOD` = LOD) |> 
-    dplyr::select(-LOD) |> 
+    dplyr::mutate(`Plate LOD` = LOD) |>
+    dplyr::select(-LOD) |>
     olink_bridgeselector(sampleMissingFreq = 0.1, n = 8)
   p_l_data <- npx_data1 |>
-    dplyr::mutate(Plate_LOD = LOD) |> 
-    dplyr::select(-LOD) |> 
+    dplyr::mutate(Plate_LOD = LOD) |>
+    dplyr::select(-LOD) |>
+    olink_bridgeselector(sampleMissingFreq = 0.1, n = 8)
+  lodnpx_data <- npx_data1 |>
+    dplyr::mutate(LODNPX = LOD) |>
+    dplyr::select(-LOD) |>
     olink_bridgeselector(sampleMissingFreq = 0.1, n = 8)
   sampleqc_data <- npx_data1 |>
-    dplyr::mutate(SampleQC = QC_Warning) |> 
-    dplyr::select(-QC_Warning) |> 
+    dplyr::mutate(SampleQC = QC_Warning) |>
+    dplyr::select(-QC_Warning) |>
     olink_bridgeselector(sampleMissingFreq = 0.1, n = 8)
   expect_length(c(setdiff(ref_data$SampleID, ml_data$SampleID),
                   setdiff(ml_data$SampleID, ref_data$SampleID)), 0)
@@ -38,6 +42,8 @@ test_that("olink_bridgeselector works", {
                   setdiff(p_l_data$SampleID, ref_data$SampleID)), 0)
   expect_length(c(setdiff(ref_data$SampleID, sampleqc_data$SampleID),
                   setdiff(sampleqc_data$SampleID, ref_data$SampleID)), 0)
+  expect_length(c(setdiff(ref_data$SampleID,lodnpx_data$SampleID),
+                  setdiff(lodnpx_data$SampleID, ref_data$SampleID)), 0)
 })
 
 test_that("olink_bridgeselector max num of samples works", {
